/* #undef HAVE_GLIB_CONFIG */
/* #undef PACKAGE */
/* #undef VERSION */
#undef HAVE_LIMITED_WRITEV

/* Define if you want to indent the output code.  */
#undef HAVE_INDENT

/* Define if HAVE_INDENT is defined and you want to indent the output code in K&R style.  */
#undef HAVE_INDENT_KR
#undef HAVE_INET_ATON
#undef ORBIT_SERIAL

#undef  ALIGNOF_CORBA_BOOLEAN
#undef  ALIGNOF_CORBA_CHAR
#undef  ALIGNOF_CORBA_DOUBLE
#undef  ALIGNOF_CORBA_FLOAT
#undef  ALIGNOF_CORBA_LONG
#undef  ALIGNOF_CORBA_LONG_DOUBLE
#undef  ALIGNOF_CORBA_LONG_LONG
#undef  ALIGNOF_CORBA_OCTET
#undef  ALIGNOF_CORBA_SHORT
#undef  ALIGNOF_CORBA_STRUCT
#undef  ALIGNOF_CORBA_UNSIGNED_LONG
#undef  ALIGNOF_CORBA_UNSIGNED_LONG_LONG
#undef  ALIGNOF_CORBA_UNSIGNED_SHORT
#undef  ALIGNOF_CORBA_WCHAR
#undef  ALIGNOF_CORBA_POINTER

/* TCP wrappers */
#undef HAVE_HOSTS_ACCESS
#undef HAVE_TCPD_H
